==> pandora_box-0.14.4.tar.gz: syd-pandora-0.14.4/src/kernel/net/connect.rs <==
//
// Syd: rock-solid application kernel
// src/kernel/net/connect.rs: connect(2) handler
//
// Copyright (c) 2023, 2024, 2025 Ali Polatel <alip@chesswob.org>
//
// SPDX-License-Identifier: GPL-3.0

use std::os::fd::{AsRawFd, OwnedFd};

use libseccomp::ScmpNotifResp;
use nix::{
    errno::Errno,
    sys::socket::{connect, AddressFamily, SockaddrLike, SockaddrStorage},
};

use crate::{
    fs::{get_nonblock, has_recv_timeout},
    hook::UNotifyEventRequest,
    kernel::net::handle_safe_bind,
};

pub(crate) fn handle_connect(
    fd: OwnedFd,
    addr: &SockaddrStorage,
    request: &UNotifyEventRequest,
    allow_safe_bind: bool,
) -> Result<ScmpNotifResp, Errno> {
    // SAFETY: Record blocking call so it can get invalidated.
    let req = request.scmpreq;
    let is_blocking = if !get_nonblock(&fd)? {
        let ignore_restart = has_recv_timeout(&fd)?;

        // Record the blocking call.
        request.cache.add_sys_block(req, ignore_restart)?;

        true
    } else {
        false
    };

    let result = connect(fd.as_raw_fd(), addr).map(|_| request.return_syscall(0));

    // Remove invalidation record unless interrupted.
    if is_blocking && !matches!(result, Err(Errno::EINTR)) {
        request.cache.del_sys_block(req.id);
    }

    // Handle allow_safe_bind.
    // Ignore errors as connect has already succeeded.
    if allow_safe_bind
        && result.is_ok()
        && matches!(
            addr.family(),
            Some(AddressFamily::Inet | AddressFamily::Inet6)
        )
    {
        let _ = handle_safe_bind(request, &fd);
    }

    result
}

==> pandora_box-0.15.0.tar.gz: syd-pandora-0.15.0/src/kernel/net/connect.rs <==
//
// Syd: rock-solid application kernel
// src/kernel/net/connect.rs: connect(2) handler
//
// Copyright (c) 2023, 2024, 2025 Ali Polatel <alip@chesswob.org>
//
// SPDX-License-Identifier: GPL-3.0

use std::os::fd::{AsRawFd, OwnedFd};

use libseccomp::ScmpNotifResp;
use nix::{
    errno::Errno,
    sys::socket::{connect, AddressFamily, SockaddrLike, SockaddrStorage},
};

use crate::{
    fs::{get_nonblock, has_recv_timeout},
    hook::UNotifyEventRequest,
    kernel::net::handle_safe_bind,
};

pub(crate) fn handle_connect(
    fd: OwnedFd,
    addr: &SockaddrStorage,
    request: &UNotifyEventRequest,
    allow_safe_bind: bool,
) -> Result<ScmpNotifResp, Errno> {
    // SAFETY: Record blocking call so it can get invalidated.
    let req = request.scmpreq;
    let is_blocking = if !get_nonblock(&fd)? {
        let ignore_restart = has_recv_timeout(&fd)?;

        // Record the blocking call.
        request.cache.add_sys_block(req, ignore_restart)?;

        true
    } else {
        false
    };

    let result = connect(fd.as_raw_fd(), addr).map(|_| request.return_syscall(0));

    // Remove invalidation record unless interrupted.
    if is_blocking {
        request
            .cache
            .del_sys_block(req.id, matches!(result, Err(Errno::EINTR)))?;
    }

    // Handle allow_safe_bind.
    // Ignore errors as connect has already succeeded.
    if allow_safe_bind
        && result.is_ok()
        && matches!(
            addr.family(),
            Some(AddressFamily::Inet | AddressFamily::Inet6)
        )
    {
        let _ = handle_safe_bind(request, &fd);
    }

    result
}
